# Quadratic programming examples

Examples are roughly sorted from simple to complex.

## Basics

1. [Quadratic program](01_quadratic_program.py)
2. [Linear least squares](02_least_squares.py)
3. [Box inequalities](03_box_inequalities.py)
4. [Sparse linear least squares](04_sparse_least_squares.py)

## Advanced

5. [Dual multipliers](05_dual_multipliers.py)

## Applications

Feel free to share yours in [Show and tell](https://github.com/stephane-caron/qpsolvers/discussions/categories/show-and-tell)!

- [Constrained linear regression](constrained_linear_regression.py)
- [Model predictive control for humanoid locomotion](model_predictive_control.py)
